@@ -1,3 +1,4 @@
+import { normalize as normalizePath } from "path";
 import { ImageType } from "./types";
 
 export function getImageType(targetImage: string): ImageType {
@@ -15,14 +16,16 @@ export function getImageType(targetImage: string): ImageType {
 }
 
 export function getArchivePath(targetImage: string): string {
-  // strip the "docker-archive:" or "oci-archive:" prefix
-
-  const path = targetImage.split(":")[1];
-  if (!path) {
+  if (
+    !targetImage.startsWith("docker-archive:") &&
+    !targetImage.startsWith("oci-archive:")
+  ) {
     throw new Error(
       'The provided archive path is missing image specific prefix, eg."docker-archive:" or "oci-archive:"',
     );
   }
 
-  return path;
+  return targetImage.indexOf("docker-archive:") !== -1
+    ? normalizePath(targetImage.substring("docker-archive:".length))
+    : normalizePath(targetImage.substring("oci-archive:".length));
 }
